/** @file depend.h

	Skelton for retropc emulator


	@author Sasaji
	@date   2012.03.01

	@brief [ dependency definition ]
*/

#ifndef _DEPEND_H_
#define _DEPEND_H_

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "common.h"

#ifdef USE_BIG_ENDIAN
inline uint16_t swap16(uint16_t x);
inline uint32_t swap32(uint32_t x);
inline uint64_t swap64(uint64_t x);
#define Int16_LE(x) (int16_t)swap16((uint16_t)(x))
#define Int32_LE(x) (int32_t)swap32((uint32_t)(x))
#define Int64_LE(x) (int64_t)swap64((uint64_t)(x))
#define Uint16_LE(x) swap16(x)
#define Uint32_LE(x) swap32(x)
#define Uint64_LE(x) swap64(x)
#else
#define Int16_LE(x) (x)
#define Int32_LE(x) (x)
#define Int64_LE(x) (x)
#define Uint16_LE(x) (x)
#define Uint32_LE(x) (x)
#define Uint64_LE(x) (x)
#endif

uint16_t conv_to_uint16_le(uint8_t *);
uint32_t conv_to_uint32_le(uint8_t *);
void conv_from_uint16_le(uint8_t *, uint16_t);
void conv_from_uint32_le(uint8_t *, uint32_t);

#ifndef MAX
#define MAX(a,b) ((a) > (b) ? (a) : (b))
#endif
#ifndef MIN
#define MIN(a,b) ((a) < (b) ? (a) : (b))
#endif


#ifndef _MAX_PATH
#define _MAX_PATH	(260)
#endif

#define TO_BCD_LO(v)	((v) % 10)
#define TO_BCD_HI(v)	(int)(((v) % 100) / 10)


/* Support Outside Ledbox */
#if defined(_WIN32) \
 ||(defined(__APPLE__) && defined(__MACH__)) \
 || defined(USE_SDL2_LEDBOX) \
 || defined(USE_X11_LEDBOX) \
 || defined(USE_GTK_LEDBOX)
#define USE_OUTSIDE_LEDBOX 1
#endif


#ifdef _UNICODE
	/* _UNICODE */

#ifndef _WIN32
wchar_t *_wgetenv(const wchar_t *);
int _wsystem(const wchar_t *);
int swprintf(wchar_t *ws, const wchar_t *format, ...);
int vswprintf(wchar_t *ws, const wchar_t *format, va_list arg);

#  ifdef _tcsicmp
#  undef _tcsicmp
#  endif
#  define _tcsicmp wcscasecmp

# endif /* !_WIN32 */

#else	/* !_UNICODE */

# ifndef _WIN32

#  ifdef _tcsicmp
#  undef _tcsicmp
#  endif
#  define _tcsicmp strcasecmp

# endif /* !_WIN32 */

#endif	/* _UNICODE */

#endif	/* _DEPEND_H_ */
